Re-exports
pub use schema::ParsedSchema;pub use schema::SchemaError;
Modules
Structs
- Render
Opts - Options controlling how a protobuf binary payload is rendered as text.
Enums
- Codec
Error - Errors that can occur while decoding or encoding a protobuf payload.
Functions
- parse_
schema - Parse a compiled
.pbdescriptor into aParsedSchema. - render_
as_ bytes - Encode a textual prototext payload back to raw protobuf binary wire bytes.
- render_
as_ text - Decode a raw protobuf binary payload and render it as protoc-style text.